<?php
namespace FM\Service;

use FM\Factory\DashboardFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;

class DashboardService {

    protected $connection;
    protected $DashboardFactory;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, DashboardFactory $DashboardFactory, Environment $Environment, NewCode $newCode) {
        $this->connection                   = $entityManager->getConnection();
        $this->DashboardFactory             = $DashboardFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function getDadosLimpezaFinalizada() {

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );

        return $this->DashboardFactory->getDadosLimpezaFinalizada($params);
    }

    public function getDadosTarefaAtrasada() {

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );

        return $this->DashboardFactory->getDadosTarefaAtrasada($params);
    }

    public function getDadosTarefaConcluida() {

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );

        return $this->DashboardFactory->getDadosTarefaConcluida($params);
    }

    public function getDadosProgress(){

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );

        $countTarefasConcluidas = $this->DashboardFactory->countTarefasConcluidas($params);
        $countTarefas  = $this->DashboardFactory->countTarefas($params);
        return[$countTarefasConcluidas,$countTarefas];
    }

    // requisição para retorno dos dados para o card (Ultimas Tarefas Realizadas) Dashboard Supervisor
    public function getDadosUltimasTarefas() {
        
        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );

        return $this->DashboardFactory->getDadosUltimasTarefas($params);
    }
    // requisição para retorno dos dados para o card (Resumo de Tarefas) Dashboard Supervisor(Tarefas Diárias)
    public function getDadosResumoTarefas() {

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );

        return $this->DashboardFactory->getDadosResumoTarefas($params);
    }

    public function findLocal() {
        return $this->DashboardFactory->findLocal();
    }
    
    // requisição para retorno dos dados do grafico Tarefas Realizadas Dashboard Supervisor
    public function getDadosChartTarefas() {

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );
        
        $selectDadosGraficos = $this->DashboardFactory->getDadosChartTarefas($params);

        return $selectDadosGraficos;
    }

    // requisição para retorno dos dados para o grafico Não Conformidades Dashboard Supervisor
    public function getDadosChartNaoConformidades() {

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );

        $dadosChartNaoConformidades = $this->DashboardFactory->getDadosChartNaoConformidades($params);

        return $dadosChartNaoConformidades;
    }

    // requisição para retorno dos dados para grafico Progresso Diario Dashboard Supervisor(Tarefas Diárias)
    public function getDadosChartProgressoDiario() {

        $params = array (
            "CDOPERADOR" => $this->Environment->getCdOperador()
        );
        
        $dadosChartProgressoDiario = $this->DashboardFactory->countTarefasConcluidasDia($params);

        return $dadosChartProgressoDiario;
    }

    // ------ REQUISIÇÕES DA TELA DE DASHBOARD (GERENCIAL) ----------

    public function setActivities() {

        $activities = $this->DashboardFactory->setActivities();
        return $activities;
    }

    public function getLocals($id) {

        $locals = $this->DashboardFactory->getLocals($id);
        return $locals;
    }

    public function dataBaseChartBarUnconformities($parametro) {

        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }


        $dbcb = $this->DashboardFactory->dataBaseChartBarUnconformities($param, $paramAct);
        return $dbcb;
    }

    public function dataBaseChartPieClean($parametro) {
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartPieClean($param, $paramAct);
        return $dbcp;
    }

    public function dataBaseChartBarAvgTime($parametro) {
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = "  AND LCPAI.NRLOCALCLIENTEPAI = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartBarAvgTime($param, $paramAct);
        return $dbcp;
    }

    public function dataBaseChartPieUnit($parametro) {
        // debugApi([$parametro]);
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND FCM_LOCALCLI.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartPieUnit($param, $paramAct);
        return $dbcp;
    }

    public function latestReports() {

        $reports = $this->DashboardFactory->latestReports();
        return $reports;
    }
    
    public function percentageTasks($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids
      $values = array (
          $this->DashboardFactory->percentageAllTasks($usersIds),
          $this->DashboardFactory->percentageTasksCompleted($usersIds)
        );
        return $values;
    }
    
    public function tasksCompleted($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids

      $tasks = $this->DashboardFactory->tasksCompleted($usersIds);
      return $tasks;
    }
    
    public function tasksLate($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $tasksLate = $this->DashboardFactory->tasksLate($usersIds);
      return $tasksLate;
    }
    
    public function lastTasksPerformed($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids

      $lastTask = $this->DashboardFactory->lastTasksPerformed($usersIds);
      return $lastTask;
    }
    
    public function dataBaseChartPie($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $dbcp = $this->DashboardFactory->dataBaseChartPie($usersIds);
      // debugApi([$dbcp]);
      return $dbcp;
    }
    
    public function dataBaseChartBar($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $dbcb = $this->DashboardFactory->dataBaseChartBar($usersIds);
      return $dbcb;
    }
}