<?php
namespace FM\Service;

use FM\Factory\FuncionariosHierarqFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class FuncionariosHierarqService {
    
    protected $connection;
    protected $FuncionariosHierarqFactory;
    protected $Environment;
    protected $newCode;
    
    public function __construct (EntityManager $entityManager, FuncionariosHierarqFactory $FuncionariosHierarqFactory, Environment $Environment, NewCode $newCode) {
        $this->connection                   = $entityManager->getConnection();
        $this->FuncionariosHierarqFactory   = $FuncionariosHierarqFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }
    
    // Busca toda a ramificação de usuários da hierarquia
    public function getHierarchyDetails($nrhierarquiafunc) {
        return $this->FuncionariosHierarqFactory->getHierarchyDetails($nrhierarquiafunc);
    }

    public function getHierarquiaFacilities($parametros) {
        $param = array (
            "NRFUNCIONARIO" => $parametros['NRFUNCIONARIO']
        );
        
        return $this->FuncionariosHierarqFactory->getHierarquiaFacilities($param);
    }

    // Busca uma lista personalizada de usuários que podem ser adicionados na hierarquia
    public function getHierarchyUsers($nrhierarquiafunc){
        return $this->FuncionariosHierarqFactory->getHierarchyUsers($nrhierarquiafunc);
    }
    
    // Busca uma lista personalizada de usuários que podem ser Pais na hierarquia
    public function getHierarchyUsersParents($nrhierarquiafunc){

        return $this->FuncionariosHierarqFactory->getHierarchyUsersParents($nrhierarquiafunc);
    }
    
    // Insere um novo usuário à hierarquia
    public function insertHierarchyUser($params){
        $nrfuncionarioshierarq = $this->newCode->getCodeByTableName('FCM_FUNCIONARIOSHIERARQ',  $this->Environment->getNrOrg(), 1, 10, true);
        
        $paramsUsers = array( 
            'NRFUNCIONARIOSHIERARQ' => $nrfuncionarioshierarq,
            'NRHIERARQUIAFUNC' => $params['params']['NRHIERARQUIAFUNC'],
            'NRFUNCIONARIO' => $params['params']['NRFUNCIONARIO'] ,
            'NRFUNCIONARIOPAI' =>$params['params']['NRFUNCIONARIOPAI'] 
        );
        
        try {
            $this->FuncionariosHierarqFactory->insertHierarchyUser($paramsUsers);
            $response = 'Inserido com sucesso';
            
        }  catch(\Exception $e) {
            $response = $e->getMessage();
        }

        return $response;
    }
    
    // Deleta um usuário e sua ramificação abaixo
    public function deleteHierarchyUser($params){
        $usersId = $params['params'];
        
        $this->connection->beginTransaction();
        try {
            foreach($usersId as $nrfuncionario) {
                $this->FuncionariosHierarqFactory->deleteHierarchyUser($nrfuncionario);
           }
           $this->connection->commit();
           $response = 'Deletado com sucesso';
        } catch(\Exception $e) {
            $this->connection->rollback();
            $response = $e->getMessage();
        }

        return $response;
    }
}
?>