import {
  Metadata, IDictionary,
  IEventParam, Router,
  Http, Loader,
} from '@zeedhi/core';
import {
  Select, Form, Text, DialogService,
  TextInput, Button, AlertService,
} from '@zeedhi/common';
import { getRouteParams } from '../router';

export class LocalController {
  public dataValue: string = '';

  public editable = false;

  public test = Loader.getInstance('GerenciarLocaisController');

  // Setando os dados do campo vindos do back
  public setDados(nome: string, code: number) {
    return {
      name: nome,
      value: code,
    };
  }

  public async setAba() {
    await localStorage.setItem('AbaAtiva', '1');
    Router.replace('/gerenciarLocais');
  }

  // protótipo de card
  get dadosTarefa() {
    return {
      name: 'ColunaCard',
      component: 'ZdCol',
      children: [
        {
          name: 'Cards',
          component: 'ZdCard',
          children: [
            {
              name: 'linhaInterna',
              component: 'ZdRow',
              children: [
                {
                  name: 'Col',
                  component: 'ZdCol',
                  cols: '2',
                  children: [
                    {
                      name: 'linha',
                      component: 'ZdText',
                      text: '<v-icon>mdi-toilet</v-icon> Limpeza de Banheiro',
                    },
                  ],
                },
                {
                  name: 'Col',
                  component: 'ZdCol',
                  cols: '2',
                  children: [
                    {
                      name: 'linha',
                      component: 'ZdText',
                      text: 'Banheiro #120 | 3 Andar',
                    },
                  ],
                },
                {
                  name: 'Col',
                  component: 'ZdCol',
                  cols: '2',
                  children: [
                    {
                      name: 'linha',
                      component: 'ZdText',
                      text: '26/10/2020 - 06 às 07:00',
                    },
                  ],
                },
                {
                  name: 'Col',
                  component: 'ZdCol',
                  cols: '2',
                  children: [
                    {
                      name: 'linha',
                      component: 'ZdText',
                      text: 'Maria Izadora Silva',
                    },
                  ],
                },
                {
                  name: 'Col',
                  component: 'ZdCol',
                  cols: '4',
                  children: [
                    {
                      name: 'linhaInterna',
                      component: 'ZdRow',
                      cssClass: 'zd-justify-end',
                      children: [
                        {
                          name: 'linha',
                          component: 'ZdText',
                          text: 'Finalizado',
                        },
                      ],
                    },
                  ],
                },
              ],
            },
          ],
        },
      ],
    };
  }

  // Pegando info de um select
  get selectedItemObject() {
    const selectObject = Metadata.getInstance<Select>('localType');
    const itemsText = (selectObject.value);
    return `${JSON.stringify(itemsText)}`;
  }

  // Procurar o pai correspondente
  public getParent(component: IEventParam<any>, nameComponent: string): any {
    if (component.component === nameComponent) {
      return component;
    }
    if (component.parent) {
      return this.getParent(component.parent, nameComponent);
    }
    return null;
  }

  // Forms Validation para botão criar
  public createClick() {
    const formObject = Metadata.getInstance<Form>('input_form');

    if (formObject.validate()) {
      this.insertLocalInfos();
    }
  }

  /*  --------- Insert ----------  */

  public insertLocalInfos() {
    const params = {
      NMTIPOLOCALCLI: Metadata.getInstance<TextInput>('nameInput').value,
      IDTIPOLOCALCLI: Metadata.getInstance<Select>('localType').value,
      IDATIVO: 'S',
      NRORG: 20,
      NRORGINCLUSAO: 20,
      DSTIPOLOCALCLI: Metadata.getInstance<Select>('description').value,
    };
    Http.post('/insertLocal', { params }).then((response: IDictionary) => {
      if (response.data.dataset.options.message !== 'Inserido com sucesso') {
        DialogService.show({
          name: 'dialogLocal',
          type: 'error',
          title: 'Erro!',
          text: 'Não foi possível inserir um novo tipo de local.',
        });
      } else {
        localStorage.setItem('AbaAtiva', '1');
        AlertService.show({
          name: 'buttons-alert',
          text: 'Tipo de Local Inserido com suceso!',
          color: 'success',
          top: true,
          left: false,
        });
        Router.replace('/gerenciarLocais');
      }
    });
  }

  /*  --------- Update ----------  */

  // Pega os dados do tipo de local para update
  public updateLocalInfos() {
    // Chamar a tela, mudar de rota para  "/tipolocal"
    const routeParams = getRouteParams();
    const { nrtipolocalcli } = routeParams;
    Http.post('/getLocalToUpdate', { nrtipolocalcli }).then((response) => {
      response.data.dataset.options.forEach((dados: IDictionary) => {
        Metadata.getInstance<Text>('nr').text = dados.NRTIPOLOCALCLI;
        Metadata.getInstance<TextInput>('nameInput').value = dados.NMTIPOLOCALCLI;
        Metadata.getInstance<Select>('localType').setValue(Number(dados.IDTIPOLOCALCLI));
        Metadata.getInstance<TextInput>('description').value = dados.DSTIPOLOCALCLI;
        this.setUpdate();
      });
    });
  }

  // Muda o label do botao criar e chama atribui o evento de click update para ele
  public setUpdate() {
    const buttonObject = Metadata.getInstance<Button>('saveButtonLocal');
    buttonObject.label = 'Salvar';
    buttonObject.events = {
      click: () => this.finalUpdate(),
    };
  }

  // Atualiza os dados do tipo de local
  public finalUpdate() {
    const params = {
      NRTIPOLOCALCLI: Metadata.getInstance<Text>('nr').text,
      NMTIPOLOCALCLI: Metadata.getInstance<TextInput>('nameInput').value,
      IDTIPOLOCALCLI: Metadata.getInstance<Select>('localType').value,
      DSTIPOLOCALCLI: Metadata.getInstance<Select>('description').value,
    };
    Router.replace('/gerenciarLocais');
    Http.post('/updateLocal', { params }).then((response: IDictionary) => {
      if (response.data.dataset.options.message !== 'Alterado com sucesso') {
        DialogService.show({
          name: 'dialogLocal',
          type: 'error',
          title: 'Erro!',
          text: 'Não foi possível editar o tipo de local.',
        });
      } else {
        AlertService.show({
          name: 'buttons-alert',
          text: 'Tipo de Local editado com suceso!',
          color: 'success',
          top: true,
          left: false,
        });
      }
    });
  }
}
